# --------------
# Analysis acoustic anchor
# --------------
library(lme4)
library(tidyverse)
library(grid)
library(latex2exp)
library(extrafont)
library(plyr)

results <- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>% filter(interval_type != "LE2A")

results$sonority <- 0
results[results$triplet == 1,]$sonority <- 111 
results[results$triplet == 2,]$sonority <- 132
results[results$triplet == 3,]$sonority <- 311
results[results$triplet == 4,]$sonority <- 321  
results[results$triplet == 5,]$sonority <- 123
results[results$triplet == 6,]$sonority <- 412
results[results$triplet == 7,]$sonority <- 112
results[results$triplet == 8,]$sonority <- 134
results[results$triplet == 9,]$sonority <- 213
results$sonority <- as.factor(results$sonority)

results$interval_type <- factor(results$interval_type, levels = c("CC2A",  "RE2A"))
contrasts(results$interval_type) <- contr.sum(2)
colnames(contrasts(results$interval_type)) <- c("RE2A-CC2A")
rownames(contrasts(results$interval_type)) <- c("CC2A", "RE2A")

results$sonority <- as.factor(results$sonority)

results$CC_CvsCCV <- ifelse(results$cond == "d", -1, ifelse(results$cond == "e", 1, 0))
results$CC_CCvsCCCV <- ifelse(results$cond == "e", -1, ifelse(results$cond == "f", 1, 0))

results$RE_CvsCCV <- ifelse(results$cond == "g", -1, ifelse(results$cond == "h", 1, 0))
results$RE_CCvsCCCV <- ifelse(results$cond == "h", -1, ifelse(results$cond == "i", 1, 0))

tvals <- data.frame(row.names = 1:4)
tvals$interval <- rep(c("CC2A", "RE2A"),each = 2)
tvals$contrast <- rep(c("CCV-CV", "CCCV-CCV"), 2)
results$triplet <- as.factor(results$triplet)

for( tr in levels(results$triplet)){
  m1 <- lmer(log(froP_V) ~ 
             CC_CvsCCV + CC_CCvsCCCV + 
             RE_CvsCCV + RE_CCvsCCCV + 
             interval_type
         + (1 + cluster +interval_type | subject)
         + (1 + interval_type | word:repl), REML = FALSE,
         data = subset(results, triplet == tr))
  
  tvals <- cbind(tvals, summary(m1)$coef[2:5,3])
  names(tvals)[ncol(tvals)] <- tr
}

tvalsDf <- tvals %>% gather("triplet", "tvals", -contrast, -interval)

ipa <- c('\u{0283}', '\u{0292}')

sh<- paste(ipa[1],"a~m", sep = "")
sh1 <- paste(ipa[1],"a~km", sep = "")
sh2 <- paste(ipa[1], "a", sep="")

sh<- paste(sh,sh1,sep ="")
sh<- paste(sh,sh2,sep="")

dg <- paste(ipa[2],"bna",sep="")
dg<-paste("na~bna~",dg, sep="")

tvalsDf$interval <- as.factor(tvalsDf$interval)
tvalsDf$interval <- factor(tvalsDf$interval, levels(tvalsDf$interval)[c(1,2)])
tvalsDf$triplet <- as.factor(tvalsDf$triplet)
tvalsDf$triplet <- factor(tvalsDf$triplet, levels(tvalsDf$triplet))
tmp <- unique(results[,c("triplet", "sonority")])
tvalsDf <- merge(tvalsDf, tmp, by= "triplet")
tvalsDf$triplet <- revalue(tvalsDf$triplet, c("1"= "ba~dba~kdba", "2"= sh,"3"="ga~bga~nbga", "4"="ka~ska~mska","5"="ma~sma~bsma", "6"="sa~bsa~lbsa","7"="za~bza~dbza", "8"="la~mla~gmla", "9"=dg ))
tvalsDf$triplet <- paste(tvalsDf$sonority, tvalsDf$triplet, sep = ": ")

tvalsDf$contrast <- factor(tvalsDf$contrast, ordered = TRUE, levels = c("CCV-CV", "CCCV-CCV"))


# Plot t-value and p-value for each contrast per triplet
plot <- ggplot(data = tvalsDf, aes(x = contrast, y = tvals, shape=interval)
               )+ geom_point() 

none <- element_blank()
plot <- plot + xlab("")
plot <- plot + ylab("t-value")
plot <- plot + theme_bw()
plot <- plot + facet_wrap(~triplet, ncol = 3)#, labeller = i_labeller

plot <- plot + geom_hline(yintercept = 2, linetype = "dotdash", color = "darkgrey")
plot <- plot + theme(panel.grid.major = none)
plot <- plot + theme(panel.grid.minor = none)

plot <- plot + scale_shape_manual(values=c(1, 19), 
                                  name = "Interval type",
                                       breaks = c("CC2A", "RE2A"),
                                       labels = c("Global timing", 
                                                  "Local timing"))

(plot <- plot + theme(
  legend.background = element_rect(colour = NA, fill="transparent"), 
  legend.position = "top", 
  legend.title = element_text(size = 9),
  legend.text = element_text(size = 9)
  ))
plot <- plot + theme(legend.key = none) +  theme(legend.key.height=unit(1,"line"))

plot <- plot + scale_y_continuous(breaks=seq(-2, 12, 2))
plot <- plot + theme(
  axis.text.y =element_text(size=8),
  axis.text.x =element_text(size=8),
  axis.ticks.x = none,
  axis.title=element_text(vjust=0.8, size =9),
  strip.text.x = element_text(face="bold", size = 8),
  #  strip.text.y = element_text(face="bold", size = 9, angle = 360),
  strip.background = element_rect( fill = "transparent"))
plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                     plot.background = element_rect(fill = "transparent",colour = NA))
plot
cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/tvals.pdf", family="Times", bg = "transparent", width = 5, height = 6)
plot
dev.off()



