# --------------
# Analysis acoustic anchor
# --------------
rm(list=ls())
library(MASS)
library(car)
library(lmerTest)
library(xtable)
library(lattice)
library(plyr)
library(ggplot2)
library(reshape)
library(tidyverse)


results<- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>% filter(interval_type != "LE2A")

# log interval
b <- boxcox(AccOff_V ~ 1, data = results)
lambda <- b$x;lik<- b$y;bc<- cbind(lambda, lik)
head(bc <- bc[order(-lik),]) # L = -.18
(lambda <- bc[1,1])
hist(log(results$AccOff_V), breaks =  50)
symbox(~AccOff_V, results)

# Contrasts
results$interval_type <- factor(results$interval_type, levels = c("CC2A", "RE2A"))
results$cluster <- factor(results$cluster, levels = c("CCV", "CCCV", "CV"))

contrasts(results$cluster) <- contr.treatment(3)
colnames(contrasts(results$cluster)) <- c("CCCV-CCV", "CV-CCV")
rownames(contrasts(results$cluster)) <- c("CCV", "CCCV", "CV")

contrasts(results$interval_type) <- contr.sum(2)
colnames(contrasts(results$interval_type)) <- c("RE2A-CC2A")
rownames(contrasts(results$interval_type)) <- c("CC2A", "RE2A")


m_pars2 <-lmer(log(AccOff_V) ~ cluster + interval_type + cluster:interval_type  
               + (1 + cluster  + interval_type| subject)
               + (1 | word:repl)
               + (1 + cluster + interval_type| triplet), 
               results)
summary(m_pars2)$coef
#anova(m_pars2)

mClean = round(summary(m_pars2)$coef,2)
colnames(mClean) <- c("est.", "SE", "df", "t", "p")
mClean[,5] <- "< 0.001"
mClean <- mClean[,-c(2,3)]

rownames(mClean) <- c("(Intercept)", "CCCV-CCV", "CV-CCV", "Local-Global", 
                      "{CCCV, CCV}:{Local timing, Global timing}",
                      "{CV, CCV}:{Local timing, Global timing}"
)

print(xtable(mClean, caption = "", label = "tab:m1",
             digits = c(0,2,2,3)), table.placement = "!h",
      caption.placement = "top")


#results$LE_CvsCCV <- ifelse(results$cond == "a", -1, ifelse(results$cond == "b", 1, 0))
#results$LE_CCvsCCCV <- ifelse(results$cond == "b", -1, ifelse(results$cond == "c", 1, 0))

results$CC_CvsCCV <- ifelse(results$cond == "d", -1, ifelse(results$cond == "e", 1, 0))
results$CC_CCvsCCCV <- ifelse(results$cond == "e", -1, ifelse(results$cond == "f", 1, 0))

results$RE_CvsCCV <- ifelse(results$cond == "g", -1, ifelse(results$cond == "h", 1, 0))
results$RE_CCvsCCCV <- ifelse(results$cond == "h", -1, ifelse(results$cond == "i", 1, 0))

m2 <- lmer(log(AccOff_V) ~ CC_CvsCCV + CC_CCvsCCCV + RE_CvsCCV + RE_CCvsCCCV  + interval_type
           + (1 + cluster + interval_type|subject) 
           + (1 | word:repl) 
           + (1 + cluster + interval_type|triplet) 
           , results)
summary(m2)$coef

(m2Clean = round(summary(m2)$coef,2))
colnames(m2Clean) <- c("est.", "SE", "df", "t", "p")
m2Clean[1:6,5] <- c(rep("< 0.001", 3), as.vector(m2Clean[c(4,5,6),5]))
m2Clean <- m2Clean[c(-1,-6),-3]

rownames(m2Clean) <- c(#"CCV-CV (textsc{LE-to-A})","CCCV-CCV (textsc{LE-to-A})",
                       "CCV-CV (Global timing)","CCCV-CCV (Global timing)",
                       "CCV-CV (Local timing)","CCCV-CCV (Local timing)"
)

print(xtable(m2Clean, caption = "", label = "tab:m2",
             digits = c(0,2,2,2,3)), table.placement = "!h",
      caption.placement = "top")


# Test model assumptions
m <- m_pars2
ranefm <- ranef(m, condVar =T) # vector with random intercepts for each subject
qqmath(ranefm)
qqPlot(ranefm$triplet[,1])
qqPlot(ranefm$subject[,1])

# Residuals should be normal distributed around 0. 
mean(residuals(m))
hist(residuals(m))

results$pred.int <- exp(fitted(m))

M <- results %>% dplyr::group_by(cluster, subject, interval_type, cond, triplet) %>% 
  dplyr::summarise(pred.int.mean = median(pred.int)) %>%
  dplyr::group_by(cond) %>%
  dplyr::summarise(M=mean(pred.int.mean),
                   SE= signif(sd(pred.int.mean)/sqrt(length(pred.int.mean)), 3) )

M$interval <- ifelse(M$cond == "d"| M$cond == "e"| M$cond == "f", "Global timing",  
                     ifelse(M$cond == "g"| M$cond == "h"| M$cond == "i", "Local timing", NA))
M$interval<-as.factor(M$interval)
M$cluster <- ifelse(M$cond == "a"| M$cond == "d"| M$cond == "g", "CV",
                    ifelse(M$cond == "b"| M$cond == "e"| M$cond == "h", "CCV",
                           ifelse(M$cond == "c"| M$cond == "f"| M$cond == "i", "CCCV", NA)))
M$cluster <-as.factor(M$cluster)
M$cluster <- factor(M$cluster, levels = c("CV", "CCV", "CCCV"))
M$interval <- factor(M$interval, levels = c("Global timing", "Local timing"))

plot <- qplot(data=M, x = cluster, y= M, 
              group = interval, 
              linetype = interval,
              xlab= NULL, ylab="Predicted interval duration (in ms)",
              geom=c("line","point")) +
  theme_bw(base_size=14) +
  scale_linetype_manual(name="Interval type:", values=c("solid", "dashed", "dotted"))
(plot <- plot + geom_errorbar(aes(max = M + 1.96*SE, min = M - 1.96*SE, width=0.05)))
none <- element_blank()
(plot <- plot + scale_y_continuous(breaks=seq(100,300,50), limits = c(120,325)))
(plot<-plot+theme(panel.background = element_rect(fill='white', colour='black')) + 
    theme( panel.grid.minor = none) + 
    theme(axis.line = element_line())) # with axis
(plot<-plot+ theme(panel.border = none))
#(plot<-plot + theme(panel.background=element_rect(colour=NA)))
(plot <- plot + theme(
#  legend.background = element_(colour = NA, fill="transparent"), 
  legend.position = "top", 
  #legend.title = element_text(family = "Times New Roman"),
  legend.text = element_text(size=14),
  legend.title = element_text(face="bold", size = 14)))
#(plot <- plot + theme(panel.grid.major.x = element_blank()))
(plot <- plot + theme(legend.key = element_blank())) #+  theme(legend.key.height=unit(1,"line")
(plot <- plot + theme(plot.title = element_text(vjust=2.5, face="bold"), 
                      axis.ticks = element_blank(), 
                      axis.text.y =element_text(size = 14),
                      axis.text.x =element_text(size = 14),
                      axis.title=element_text(vjust=0.5))) 

#(plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
 #                     plot.background = element_rect(fill = "transparent",colour = NA)))

cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/acc.pdf", family= "Times", bg = "transparent", width = 5, height = 5)
plot
dev.off()

