# ----------------
# Descriptives
# ----------------
library(plyr)
library(ggplot2)
library(latex2exp)
library(extrafont)
library(tidyverse)
library(xtable)
#font_install('fontcm')
#SE =  function(x){
#  sd(x)/sqrt(length(x))
#} 

results<- read_delim("dfs/results_preprocessed.txt", delim = "\t") %>%
# Remove a few columns to make this easier understandable
  select(file, subject, interval_type, cluster, triplet, repl, AccOff_V) %>%
  filter(subject %in% c(1:4), # which subjects
         cluster %in% c("CV", "CCV", "CCCV"), # which clusters
         interval_type != "LE2A"
  ) 
# Descriptive data Accustic offset
# Take median across repititions
data.median <- results %>% group_by(triplet, interval_type, cluster, subject) %>%
  dplyr::summarise(
    median = median(AccOff_V)
  ) %>% ungroup()


# SDs across repetiions and clusters
data.sds <- results %>% group_by(triplet, interval_type, subject) %>%
  dplyr::summarise(
    sd = sd(AccOff_V)
  ) %>% ungroup()


# Calculate means and rsds across cluster size
data.rsd <- data.median %>% group_by(triplet, interval_type, subject) %>%
  dplyr::summarise(
    mean = mean(median)
  ) %>%
  right_join(data.sds) %>%
  # calculate rsd from mean sd across cluster size
  mutate(
    rsd = (sd*100)/mean
  ) %>% 
  # Order by subject
  arrange(subject) %>%
  ungroup()


# For summary purposes get the mean of the means, sd and rsds 
# resulting from the previous by-subject statistics
data.mean <- data.rsd %>% group_by(triplet, interval_type) %>%
  dplyr::summarise(
    mean = mean (mean),
    SD = mean (sd),
    RSD = mean (rsd)) %>% ungroup()

RE2A <- data.mean %>% filter(interval_type == "RE2A") %>% select(-interval_type, -triplet)
CC2A <- data.mean %>% filter(interval_type == "CC2A") %>% select(-interval_type, -triplet)

colnames(CC2A) <- c("mean", "SD", "RSD")
colnames(RE2A) <- c("mean", "SD", "RSD")

AccOff <- cbind(1:9, CC2A, RE2A)
colnames(AccOff)[1] <- "Triplet"
AccOff <- round(AccOff,2)

AccOff$Triplet <- as.factor(AccOff$Triplet)
AccOff$Triplet <- revalue(AccOff$Triplet, c("1"= "\\textipa{ba$\\sim$dba$\\sim$kdba}", 
                                            "2"= "\\textipa{Sa$\\sim$mSa$\\sim$kmSa}",
                                            "3"="\\textipa{ga$\\sim$bga$\\sim$nbga}", 
                                            "4"="\\textipa{ka$\\sim$ska$\\sim$mska}",
                                            "5"="\\textipa{ma$\\sim$sma$\\sim$bsma}", 
                                            "6"="\\textipa{sa$\\sim$bsa$\\sim$lbsa}",
                                            "7"="\\textipa{za$\\sim$bza$\\sim$dbza}", 
                                            "8"="\\textipa{la$\\sim$mla$\\sim$gmla}", 
                                            "9"="\\textipa{na$\\sim$bna$\\sim$Zbna}" ))

AccOff %>% kable(format ="latex",booktabs = T, caption = "Data summary by-subject.") %>%
  kable_styling(full_width = T) %>%
  column_spec(1, width = "3cm") %>%
  add_header_above(c(" " = 1, "LE2A" = 3, "CC2A" = 3, "RE2A" = 3),bold = T) %>%
  group_rows("Subject 1", 1, 9) %>%
  group_rows("Subject 2", 10, 18) %>%
  group_rows("Subject 3", 19, 27) %>%
  group_rows("Subject 4", 28, 36) 


print(xtable(AccOff), include.rownames = F, sanitize.text.function = identity)



# Descriptive data Articulatory offset
data.median <- results %>% group_by(triplet, interval_type, cluster, subject) %>%
  dplyr::summarise(median = median(froP_V))

data.mean <- data.median %>% group_by(triplet, interval_type) %>%
  dplyr::summarise(mean = mean (median),
            sd = sd(median)) %>% ungroup()

data.mean$rsd <- 100*data.mean$sd/data.mean$mean

LE2A <- data.mean %>% filter(interval_type == "LE2A") %>% select(-interval_type, -triplet)
RE2A <- data.mean %>% filter(interval_type == "RE2A") %>% select(-interval_type, -triplet)
CC2A <- data.mean %>% filter(interval_type == "CC2A") %>% select(-interval_type, -triplet)

colnames(LE2A) <- c("mean", "SD", "RSD")
colnames(CC2A) <- c("mean", "SD", "RSD")
colnames(RE2A) <- c("mean", "SD", "RSD")

froP_V <- cbind(1:9, LE2A, CC2A, RE2A)
colnames(froP_V)[1] <- "Triplet"
froP_V <- round(froP_V,2)

froP_V$Triplet <- as.factor(froP_V$Triplet)
froP_V$Triplet <- revalue(froP_V$Triplet, c("1"= "\\textipa{ba$\\sim$dba$\\sim$kdba}", 
                                            "2"= "\\textipa{Sa$\\sim$mSa$\\sim$kmSa}",
                                            "3"="\\textipa{ga$\\sim$bga$\\sim$nbga}", 
                                            "4"="\\textipa{ka$\\sim$ska$\\sim$mska}",
                                            "5"="\\textipa{ma$\\sim$sma$\\sim$bsma}", 
                                            "6"="\\textipa{sa$\\sim$bsa$\\sim$lbsa}",
                                            "7"="\\textipa{za$\\sim$bza$\\sim$dbza}", 
                                            "8"="\\textipa{la$\\sim$mla$\\sim$gmla}", 
                                            "9"="\\textipa{na$\\sim$bna$\\sim$Zbna}" ))

print(xtable(froP_V), include.rownames = F, sanitize.text.function = identity)


#----
# Create Plots for descriptive data
ipa <- c('\u{0283}', '\u{0292}')

sh<- paste(ipa[1],"a~m", sep = "")
sh1 <- paste(ipa[1],"a~km", sep = "")
sh2 <- paste(ipa[1], "a", sep="")

sh<- paste(sh,sh1,sep ="")
sh<- paste(sh,sh2,sep="")

dg <- paste(ipa[2],"bna",sep="")
dg <-paste("na~bna~",dg, sep="")

results$triplet <- as.factor(results$triplet)
results$triplet <- revalue(results$triplet, c("1"= "ba~dba~kdba", "2"= sh,"3"="ga~bga~nbga", "4"="ka~ska~mska","5"="ma~sma~bsma", "6"="sa~bsa~lbsa","7"="za~bza~dbza", "8"="la~mla~gmla", "9"=dg ))

results$cluster <- factor(results$cluster, levels = c("CV", "CCV", "CCCV"))
results$interval_type <- factor(results$interval_type, levels = c("LE2A", "CC2A", "RE2A"))

i_labeller <- function(variable,value){
  value <- as.character(value)
  if (variable=="interval_type") { 
    value[value=="LE2A"] <- "LE-ᴛᴏ-A"
    value[value=="CC2A"] <- "CC-ᴛᴏ-A"
    value[value=="RE2A"] <- "RE-ᴛᴏ-A"
  #  value[value=="LE2A"] <- "LE-TO-A"
   # value[value=="CC2A"] <- "CC-TO-A"
   # value[value=="RE2A"] <- "RE-TO-A"
  }
  return(value)
}


#results$interval_type <- as.character(results$interval_type)
#results$interval_type <- mapvalues(results$interval_type, from = unique(results$interval_type), to =c(TeX("\\textsc{LE-to-A}"), TeX("\\textsc{CC-to-A}"), TeX("\\textsc{RE-to-A}")))
#mapvalues(results$cluster, from = levels(results$interval_type), to = c(TeX("\textsc{LE-to-A}"), TeX("\textsc{CC-to-A}"), TeX("\textsc{RE-to-A}"))) 
#levels(results$interval_type) <- c(TeX("\textsc{LE-to-A}"), TeX("\textsc{CC-to-A}"), TeX("\textsc{RE-to-A}"))
#results$interval_type <- factor(results$interval_type, labels = c("\textsc{LE-to-A}","\textsc{CC-to-A}","\textsc{RE-to-A}"))


(plot<- ggplot(data = results,
               aes(x = cluster, 
                   y = AccOff_V)))
(plot <- plot + xlab(""))
(plot <- plot + ylab("Interval duration (ms)"))
(plot <- plot + theme_bw(base_size=18))
(plot <- plot + geom_jitter(size=.5, width = .2))
(plot <- plot + facet_grid(triplet ~ interval_type, labeller = i_labeller))

(plot <- plot + theme(panel.grid.major = element_blank()))
(plot <- plot + theme(panel.grid.minor = element_blank()))
plot <- plot + theme(legend.position="none")
(plot <- plot + scale_y_continuous(breaks=c(100,200,300,400,500)))
(plot <- plot + stat_smooth(method="lm", se=F, aes(group=1,colour="red"),size=1) + guides(colour=FALSE))
(plot <- plot + theme(#axis.ticks = element_blank(), 
  axis.text.y =element_text(size=11),
  axis.text.x =element_text(size=15),
  axis.title=element_text(vjust=0.8, size = 17),
  strip.text.x = element_text(face="bold", size = 15),
  strip.text.y = element_text(face="italic", size = 16, angle = 360),
  strip.background = element_rect( fill = "transparent")))
(plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                      plot.background = element_rect(fill = "transparent",colour = NA)))

#pdf("/home/jens/Documents/MA_report/draft3/gfx/raw_acc.pdf", family="Times", fonts = "Times", width=12, height=16)
cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/raw_acc.pdf", family="Times", bg = "transparent", width = 10, height = 10)
plot
dev.off()


(plot<- ggplot(data = results,
              aes(x = cluster, 
              y = froP_V)))
(plot <- plot + xlab(""))
(plot <- plot + ylab("Interval duration (ms)"))
(plot <- plot + theme_bw(base_size=18))
(plot <- plot + geom_jitter(size=.5, width = .2))
(plot <- plot + facet_grid(triplet ~ interval_type, labeller = i_labeller))

(plot <- plot + theme(panel.grid.major = element_blank()))
(plot <- plot + theme(panel.grid.minor = element_blank()))
plot <- plot + theme(legend.position="none")
(plot <- plot + scale_y_continuous(breaks=c(100,200,300,400,500)))
(plot <- plot + stat_smooth(method="lm", se=F, aes(group=1,colour="red"),size=1) + guides(colour=FALSE))
(plot <- plot + theme(#axis.ticks = element_blank(), 
  axis.text.y =element_text(size=11),
  axis.text.x =element_text(size=15),
  axis.title=element_text(vjust=0.8, size = 17),
  strip.text.x = element_text(face="bold", size = 15),
  strip.text.y = element_text(face="italic", size = 16, angle = 360),
  strip.background = element_rect( fill = "transparent")))
(plot <- plot + theme(panel.background = element_rect(fill = "transparent",colour = NA), # or theme_blank()
                      plot.background = element_rect(fill = "transparent",colour = NA)))

#pdf("/home/jens/Documents/MA_report/draft3/gfx/raw_acc.pdf", family="Times", fonts = "Times", width=12, height=16)
cairo_pdf("/home/jens/Documents/MA_report/RoeserGafosHooleZeroualRevised/gfx/raw_peak.pdf", family="Times", bg = "transparent", width = 10, height = 10)
plot
dev.off()


